searchData={"items":[{"type":"module","title":"ExExport","doc":"This module inspects another module for public functions and generates the defdelegate needed to add them to the local modules name space","ref":"ExExport.html"},{"type":"function","title":"ExExport.expand_module/3","doc":"","ref":"ExExport.html#expand_module/3"},{"type":"macro","title":"ExExport.export/2","doc":"require in the module and them call export for each module you want to import.\n  The function list automatically filters out functions that start with an underscore","ref":"ExExport.html#export/2"},{"type":"macro","title":"Examples - ExExport.export/2","doc":"defmodule Sample do\n    require ExExport\n    alias  Sample.Actions.Greet\n\n    ExExport.export(Greet)\n    ExExport.export(Sample.Actions.Farewell)\n\n   end","ref":"ExExport.html#export/2-examples"},{"type":"macro","title":"Options - ExExport.export/2","doc":"* `:only` - (since v0.2.0) a list of [function: arity] only matching functions will be delegated\n  * `:exclude` - (since v0.2.0) a list of [function: arity]  matching functions will *NOT* be delegated\n  * `:expansion` - (since v.0.8.1) :manual or :macro -\n         :macro - use Macro.expand. This seems to generate a compile time dependency\n         :manual - uses custom code to figure out the alias resolution -which prevents the compile\n                   time dependency but can generate a **warning - alias is unused** because we are resolving it. You\n                   can get rid of the warning by changing to :macro, undoing the alias or adding warn: false to the alias","ref":"ExExport.html#export/2-options"},{"type":"macro","title":"See the Output - ExExport.export/2","doc":"In the configuration file for the environment you wish to render the\ndata attributes, you can set the `show_definitions`  to true. This\nwill output the code that is being injected in a readable form. This can be useful\nif you get warnings like (Cannot match because already defined)\n\n  ```elixir\n  config :ex_export, :show_definitions, true\n```","ref":"ExExport.html#export/2-see-the-output"},{"type":"function","title":"ExExport.output_definition/1","doc":"","ref":"ExExport.html#output_definition/1"},{"type":"function","title":"ExExport.show_definitions?/0","doc":"","ref":"ExExport.html#show_definitions?/0"},{"type":"extras","title":"ExExport","doc":"# ExExport\n\n This library provides an easy way to make barrel files in Elixir.\n\n      A barrel is a way to rollup exports from several modules into a single convenient module.\n      The barrel itself is a module file that re-exports selected exports of other modules.\n    \n Source: [Barasat Gitbooks](https://basarat.gitbook.io/typescript/main-1/barrel)\n\nI have grown used to having a lot of little files that get bundled up into a library (blame my time working\nin node/ES6 land).  Because of the compiled nature of Elixir it seemed like this style of file structure\nshould work without run time penalties.  \n\nThis directive is an experiment to enable that. It allows me to build API barrels the same way I do in\nJavascript.\n\n/lib\n   api.ex\n   actions/\n       welcome.ex\n       farewell.ex\n       \n       \n```elixir\n#api.ex\ndefmodule Api.Defs do\n  @moduledoc \"\"\"\n  This module has to be compiled first so that the function is available in the module scope.\n  \"\"\"\n  def exclude_list(), do: [exclude_from_function1: 1, exclude_from_function2: 1]\n  def only_list(), do: [only_from_function1: 1, only_from_function2: 1]\nend\n\ndefmodule API do\n  require ExExport\n  alias API.Actions.Welcome\n  ExExport.export(Welcome)\n  ExExport.export(API.Actions.Farewell)\n  ExExport.export(API.Actions.AllButActionFromFunction,exclude: Api.Defs.exclude_list())\n  ExExport.export(API.Actions.AllButAction,exclude: [all_but_action1: 1])\n  ExExport.export(API.Actions.OnlySomeAction,only: [some_action1: 1])\n  ExExport.export(API.Actions.OnlySomeActionFromFunction,only: Api.Defs.only_list())\n\nend      \n```\n\nThis adds defdelegate for all public methods in the referenced files. It filters out\nany methods that start with an underscore so that a method called _app_name or __info__  would be auto excluded.\n\n## :only\nThis option allows you to set a list of specific functions/arity to include.\nIf you define a function in a separate module you can use that to generate the list of\nfunction/arity that will be used.\n\n## :exclude\nThis includes all public functions except the ones matching the list of function/arity\nIf you define a function in a separate module you can use that to generate the list of\nfunction/arity that will be used.\n\n## :expansion\nThis can be :manual or :macro. Default is :manual\n\n* :macro - use Macro.expand. This seems to generate a compile time dependency\n* :manual - uses custom code to figure out the alias resolution -which prevents the compile\ntime dependency but can generate a **warning - alias is unused** because we are resolving it. You\ncan get rid of the warning by changing to :macro, undoing the alias or adding warn: false to the alias","ref":"readme.html"},{"type":"extras","title":"See the Output - ExExport","doc":"In the configuration file for the environment you wish to render the\ndata attributes, you can set the `show_definitions`  to true. This\nwill output the code that is being injected in a readable form. This can be useful\nif you get warnings like (Cannot match because already defined)\n\n```elixir\nconfig :ex_export, :show_definitions, true\n  ```","ref":"readme.html#see-the-output"},{"type":"extras","title":"Installation - ExExport","doc":"The package can be installed by adding `ex_export` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_export, \"~> 0.8.8\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at [https://hexdocs.pm/ex_export](https://hexdocs.pm/ex_export).","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE","doc":"Copyright 2020 r26D, LLC\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}